export class Popup {
    static CreatePopup(title, windowVariableName, width = 300, height = 800) {
        const windowCreationOptionsList = {
            width: width,
            height: height,
            top: (window.innerHeight - width) / 2 + window.screenY,
            left: (window.innerWidth - height) / 2 + window.screenX,
        };
        const windowCreationOptions = Object.keys(windowCreationOptionsList)
            .map((key) => key + "=" + windowCreationOptionsList[key])
            .join(",");
        const popupWindow = window.open("", title, windowCreationOptions);
        if (!popupWindow) {
            return null;
        }
        const parentDocument = popupWindow.document;
        // Font
        const newLinkEl = parentDocument.createElement("link");
        newLinkEl.rel = "stylesheet";
        newLinkEl.href = "https://use.typekit.net/cta4xsb.css";
        parentDocument.head.appendChild(newLinkEl);
        parentDocument.title = title;
        parentDocument.body.style.width = "100%";
        parentDocument.body.style.height = "100%";
        parentDocument.body.style.margin = "0";
        parentDocument.body.style.padding = "0";
        const parentControl = parentDocument.createElement("div");
        parentControl.style.width = "100%";
        parentControl.style.height = "100%";
        parentControl.style.margin = "0";
        parentControl.style.padding = "0";
        popupWindow.document.body.appendChild(parentControl);
        this._CopyStyles(window.document, parentDocument);
        setTimeout(() => {
            // need this for late bindings
            this._CopyStyles(window.document, parentDocument);
        }, 0);
        this[windowVariableName] = popupWindow;
        return parentControl;
    }
    static _CopyStyles(sourceDoc, targetDoc) {
        for (let index = 0; index < sourceDoc.styleSheets.length; index++) {
            const styleSheet = sourceDoc.styleSheets[index];
            try {
                if (styleSheet.cssRules) {
                    // for <style> elements
                    const newStyleEl = sourceDoc.createElement("style");
                    for (const cssRule of styleSheet.cssRules) {
                        // write the text of each rule into the body of the style element
                        newStyleEl.appendChild(sourceDoc.createTextNode(cssRule.cssText));
                    }
                    targetDoc.head.appendChild(newStyleEl);
                }
                else if (styleSheet.href) {
                    // for <link> elements loading CSS from a URL
                    const newLinkEl = sourceDoc.createElement("link");
                    newLinkEl.rel = "stylesheet";
                    newLinkEl.href = styleSheet.href;
                    targetDoc.head.appendChild(newLinkEl);
                }
            }
            catch (e) {
                // eslint-disable-next-line no-console
                console.log(e);
            }
        }
    }
}
//# sourceMappingURL=popup.js.map